cmd

package
v1.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 23, 2025 License: MIT Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

Types

type ProfileConfig

type ProfileConfig struct {
	Name            string
	Region          string
	AuthType        string
	SSOStartURL     string
	SSORegion       string
	SSOAccountID    string
	SSORoleName     string
	AccessKeyID     string
	SecretAccessKey string
}

Jump to